@@ -113,4 +113,4 @@ class ClockTimer:
             sec = get_time_delta_from_str(sec)
             sounds[sec] = Sound.from_dict(sound)
 
-        return ClockTimer(sounds=sounds, loop=json["loop"], title=json["title"])
+        return ClockTimer(sounds=sounds, loop=json.get("loop", 1), title=json["title"])
