@@ -38,7 +38,7 @@ def get_option_parser():
     parser.add_option(
         "-t",
         "--time",
-        dest="specified_time",
+        dest="time",
         action="store",
         help="Time which spends until or to specified",
     )
@@ -68,7 +68,7 @@ def main() -> None:
 
     if opt.show_list:
         show_list_main()
-    elif opt.specified_time is not None:
+    elif opt.time is not None:
         specified_time_main(opt, args)
     else:
         play_clock_main(opt, args)
